JsonPath

Struct JsonPath 

pub struct JsonPath { /* private fields */ }
A compiled JSONPath expression.

Implementations

Source

impl JsonPath

pub fn builder() -> JsonPathBuilder

Returns a typed JSONPath builder.

pub fn from_segments(segments: impl Into<Vec<Segment>>) -> Self

Builds a path from already typed segments.

pub fn segments(&self) -> &[Segment]

Path segments after the root $.

pub fn is_singular(&self) -> bool

Whether this path only contains exact member and index selectors.

pub fn matches_path(&self, path: &[PathElement]) -> bool

Returns whether this JSONPath matches an already tracked value path.

pub fn match_count(&self, path: &[PathElement]) -> usize

Returns how many ways this JSONPath matches an already tracked value path.

RFC 9535 selector lists preserve duplicate selections, so overlapping union members can match the same concrete path more than once.